@@ -1,14 +1,31 @@
 from __future__ import absolute_import, division, unicode_literals
 
-from django.utils.translation import ugettext_lazy as _
-from django.utils.safestring import mark_safe
-from debug_toolbar.panels import Panel
-from debug_toolbar import settings as dt_settings
-
 import cProfile
-from pstats import Stats
-from colorsys import hsv_to_rgb
 import os
+from colorsys import hsv_to_rgb
+from pstats import Stats
+
+from django.utils import six
+from django.utils.safestring import mark_safe
+from django.utils.translation import ugettext_lazy as _
+
+from debug_toolbar import settings as dt_settings
+from debug_toolbar.panels import Panel
+
+# Occasionally the disable method on the profiler is listed before
+# the actual view functions. This function call should be ignored as
+# it leads to an error within the tests.
+INVALID_PROFILER_FUNC = '_lsprof.Profiler'
+
+
+def contains_profiler(func_tuple):
+    """Helper function that checks to see if the tuple contains
+    the INVALID_PROFILE_FUNC in any string value of the tuple."""
+    has_profiler = False
+    for value in func_tuple:
+        if isinstance(value, six.string_types):
+            has_profiler |= INVALID_PROFILER_FUNC in value
+    return has_profiler
 
 
 class DjangoDebugToolbarStats(Stats):
@@ -17,7 +34,7 @@ class DjangoDebugToolbarStats(Stats):
     def get_root_func(self):
         if self.__root is None:
             for func, (cc, nc, tt, ct, callers) in self.stats.items():
-                if len(callers) == 0:
+                if len(callers) == 0 and not contains_profiler(func):
                     self.__root = func
                     break
         return self.__root
@@ -62,10 +79,10 @@ class FunctionCall(object):
             file_path, file_name = file_name.rsplit(os.sep, 1)
 
             return mark_safe(
-                '<span class="path">{0}/</span>'
-                '<span class="file">{1}</span>'
-                ' in <span class="func">{3}</span>'
-                '(<span class="lineno">{2}</span>)'.format(
+                '<span class="djdt-path">{0}/</span>'
+                '<span class="djdt-file">{1}</span>'
+                ' in <span class="djdt-func">{3}</span>'
+                '(<span class="djdt-lineno">{2}</span>)'.format(
                     file_path,
                     file_name,
                     line_num,
@@ -142,7 +159,7 @@ class ProfilingPanel(Panel):
                     func.has_subfuncs = True
                     self.add_node(func_list, subfunc, max_depth, cum_time=cum_time)
 
-    def process_response(self, request, response):
+    def generate_stats(self, request, response):
         if not hasattr(self, 'profiler'):
             return None
         # Could be delayed until the panel content is requested (perf. optim.)
@@ -155,7 +172,7 @@ class ProfilingPanel(Panel):
         func_list = []
         self.add_node(func_list,
                       root,
-                      dt_settings.CONFIG['PROFILER_MAX_DEPTH'],
+                      dt_settings.get_config()['PROFILER_MAX_DEPTH'],
                       root.stats[3] / 8)
 
         self.record_stats({'func_list': func_list})
